import { __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from "@emotion/react";
import * as React from "react";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
import { IconChevronRight } from "./Icons";
const hideScrollbar = css `
  ::-webkit-scrollbar {
    height: 0;
    width: 0;
  }
`;
/**
 * Breadcrumbs are useful to orient the user on your site,
 * especially when working with hierarchies of content.
 */
export const Breadcrumbs = (_a) => {
    var { children, size = "md", overflowX } = _a, other = __rest(_a, ["children", "size", "overflowX"]);
    const theme = useTheme();
    return (_jsx("nav", Object.assign({ className: "Breadcrumbs", "aria-label": "breadcrumb", css: [
            {
                maxWidth: "100%",
                overflow: overflowX ? "scroll" : "hidden",
                WebkitOverflowScrolling: "touch",
                scrollbarWidth: "none",
                borderRadius: theme.radii.sm,
                msOverflowStyle: "none"
            },
            hideScrollbar
        ] }, other, { children: _jsx("ol", Object.assign({ className: "Breadcrumbs__list", css: {
                listStyle: "none",
                whiteSpace: "nowrap",
                display: "inline-flex",
                boxSizing: "border-box",
                overflow: "hidden",
                maxWidth: overflowX ? undefined : "100%",
                margin: 0,
                padding: `${theme.spaces.sm} ${theme.spaces.md}`,
                borderRadius: theme.radii.md
            } }, { children: React.Children.map(children, (child, i) => {
                if (!React.isValidElement(child)) {
                    return child;
                }
                return React.cloneElement(child, {
                    size,
                    "aria-current": i === validChildrenCount(children) - 1 ? "page" : undefined
                });
            }) }), void 0) }), void 0));
};
Breadcrumbs.propTypes = {
    size: PropTypes.oneOf(["md", "lg"]),
    overflowX: PropTypes.number
};
function validChildrenCount(children) {
    return React.Children.toArray(children).filter(child => React.isValidElement(child)).length;
}
/**
 *  Each item in a list of breadcrumbs.
 */
export const BreadcrumbItem = (_a) => {
    var { children, size = "md" } = _a, other = __rest(_a, ["children", "size"]);
    const current = other["aria-current"];
    return (_jsxs("li", Object.assign({ className: "BreadcrumbItem", css: {
            flex: "0 1 auto",
            overflow: "hidden",
            display: "flex",
            alignItems: "center"
        } }, other, { children: [_jsx(Text, Object.assign({ className: "BreadcrumbItem__text", wrap: false, component: "div", variant: size === "md" ? "body" : "h5", gutter: false, css: {
                    "& > a": {
                        textDecoration: "none"
                    }
                } }, { children: children }), void 0),
            !current && _jsx(BreadcrumbDivider, {}, void 0)] }), void 0));
};
BreadcrumbItem.propTypes = {
    children: PropTypes.node,
    size: PropTypes.oneOf(["md", "lg"])
};
const BreadcrumbDivider = () => {
    const theme = useTheme();
    return (_jsx(IconChevronRight, { className: "BreadcrumbDivider", color: theme.colors.text.muted, css: {
            flex: "0 0 auto",
            margin: `0 ${theme.spaces.sm}`
        } }, void 0));
};
BreadcrumbDivider.propTypes = {
    inverted: PropTypes.bool
};
//# sourceMappingURL=Breadcrumbs.js.map