import { __rest } from "tslib";
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { Spinner } from "./Spinner";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
/**
 * 实际就是div有周边边角，圆弧突出的div
 */
export const Layer = (_a) => {
    var { elevation = "md", children } = _a, other = __rest(_a, ["elevation", "children"]);
    const theme = useTheme();
    return (_jsx("div", Object.assign({ css: {
            position: "relative",
            background: theme.colors.background.layer,
            boxShadow: theme.shadows[elevation],
            borderRadius: theme.radii.lg
        } }, other, { children: children }), void 0));
};
/**
 * 旧版本，可注入ref
 */
export const LayerRefComp = React.forwardRef((_a, ref) => {
    var { elevation = "md", children } = _a, other = __rest(_a, ["elevation", "children"]);
    const theme = useTheme();
    return (_jsx("div", Object.assign({ ref: ref, css: {
            position: "relative",
            background: theme.colors.background.layer,
            boxShadow: theme.shadows[elevation],
            borderRadius: theme.radii.lg
        } }, other, { children: children }), void 0));
});
Layer.displayName = "Layer";
Layer.propTypes = {
    elevation: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"]),
    children: PropTypes.node
};
/**淘汰掉了！    烦劳请直接用 Spinner 来替换 LayerLoading 功能；
 * */
export const LayerLoading = (_a) => {
    var { loading, label } = _a, other = __rest(_a, ["loading", "label"]);
    const theme = useTheme();
    const isDark = theme.colors.mode === "dark";
    return (_jsx("div", Object.assign({ css: {
            position: "absolute",
            top: 0,
            left: 0,
            right: 0,
            borderRadius: theme.radii.lg,
            bottom: 0,
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
            background: isDark ? "rgba(0,0,0,0.75)" : "rgba(255,255,255,0.7)",
            zIndex: 5,
            transition: "opacity 0.3s ease",
            pointerEvents: loading ? "auto" : "none",
            opacity: loading ? 1 : 0
        } }, other, { children: _jsx(Spinner, { doing: loading, label: label }, void 0) }), void 0));
};
LayerLoading.propTypes = {
    loading: PropTypes.bool,
    label: PropTypes.string
};
//# sourceMappingURL=Layer.js.map