import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { animated, useTransition } from "react-spring";
import { Portal } from "./Portal";
import { useHideBody } from "./Hooks/hide-body";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
export const Overlay = React.forwardRef(({ isOpen, onRequestClose, children }, ref) => {
    const theme = useTheme();
    const transitions = useTransition(isOpen, {
        from: { opacity: 0 },
        enter: { opacity: 1 },
        leave: { opacity: 0 }
    });
    const { bind } = useHideBody(isOpen);
    return (_jsx(Portal, { children: transitions((style, item) => {
            return (item && _jsxs("div", Object.assign({ ref: ref }, bind, { onClick: (e) => {
                    e.stopPropagation();
                    onRequestClose();
                }, onKeyDown: (e) => {
                    if (e.key === "Escape") {
                        e.stopPropagation();
                        onRequestClose();
                    }
                }, css: {
                    bottom: 0,
                    left: 0,
                    overflow: "auto",
                    width: "100vw",
                    height: "100vh",
                    zIndex: theme.zIndices.overlay,
                    position: "fixed",
                    content: "''",
                    right: 0,
                    top: 0,
                    WebkitTapHighlightColor: "transparent"
                } }, { children: [_jsx(animated.div, { style: { opacity: style.opacity }, css: [
                            {
                                position: "absolute",
                                top: 0,
                                left: 0,
                                right: 0,
                                bottom: 0,
                                background: theme.colors.background.overlay
                            }
                        ] }, void 0), children] }), 1));
        }) }, void 0));
});
Overlay.displayName = "Overlay";
Overlay.propTypes = {
    isOpen: PropTypes.bool.isRequired,
    onRequestClose: PropTypes.func.isRequired,
    children: PropTypes.node
};
//# sourceMappingURL=Overlay.js.map